

-- GovWay Configurazione

-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_users_ricerche;
DROP TRIGGER trg_users_servizi;
DROP TRIGGER trg_users_soggetti;
DROP TRIGGER trg_users_password;
DROP TRIGGER trg_users_stati;
DROP TRIGGER trg_users;
DROP TABLE users_ricerche;
DROP TABLE users_servizi;
DROP TABLE users_soggetti;
DROP TABLE users_password;
DROP TABLE users_stati;
DROP TABLE users;
DROP SEQUENCE seq_users_ricerche;
DROP SEQUENCE seq_users_servizi;
DROP SEQUENCE seq_users_soggetti;
DROP SEQUENCE seq_users_password;
DROP SEQUENCE seq_users_stati;
DROP SEQUENCE seq_users;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_audit_appender_prop;
DROP TRIGGER trg_audit_appender;
DROP TRIGGER trg_audit_filters;
DROP TRIGGER trg_audit_conf;
DROP TABLE audit_appender_prop;
DROP TABLE audit_appender;
DROP TABLE audit_filters;
DROP TABLE audit_conf;
DROP SEQUENCE seq_audit_appender_prop;
DROP SEQUENCE seq_audit_appender;
DROP SEQUENCE seq_audit_filters;
DROP SEQUENCE seq_audit_conf;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX audit_filter;
-- DROP INDEX audit_object_old_id;
-- DROP INDEX audit_object_id;
-- DROP INDEX audit_filter_time;
DROP TRIGGER trg_audit_binaries;
DROP TRIGGER trg_audit_operations;
DROP TABLE audit_binaries;
DROP TABLE audit_operations;
DROP SEQUENCE seq_audit_binaries;
DROP SEQUENCE seq_audit_operations;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX index_mapping_erogazione_pa_2;
-- DROP INDEX index_mapping_erogazione_pa_1;
-- DROP INDEX index_mapping_fruizione_pd_2;
-- DROP INDEX index_mapping_fruizione_pd_1;
DROP TRIGGER trg_mapping_erogazione_pa;
DROP TRIGGER trg_mapping_fruizione_pd;
DROP TABLE mapping_erogazione_pa;
DROP TABLE mapping_fruizione_pd;
DROP SEQUENCE seq_mapping_erogazione_pa;
DROP SEQUENCE seq_mapping_fruizione_pd;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_PA_TOKEN_SA;
-- DROP INDEX idx_pa_trasf_hdr_resp_1;
-- DROP INDEX idx_pa_trasf_url_1;
-- DROP INDEX idx_pa_trasf_hdr_1;
-- DROP INDEX INDEX_PA_CACHE;
-- DROP INDEX INDEX_PA_SA_AUTH;
-- DROP INDEX INDEX_PA_CORR_RES;
-- DROP INDEX INDEX_PA_CORR_REQ;
-- DROP INDEX INDEX_PA_WSSRES;
-- DROP INDEX INDEX_PA_WSSREQ;
-- DROP INDEX INDEX_PA_MTOMTRES;
-- DROP INDEX INDEX_PA_MTOMTREQ;
-- DROP INDEX INDEX_PA_PROP;
-- DROP INDEX INDEX_PA_CT_PROP;
-- DROP INDEX idx_pa_ct_props_1;
-- DROP INDEX INDEX_PA_AUTHZC_PROP;
-- DROP INDEX INDEX_PA_AUTHZ_PROP;
-- DROP INDEX INDEX_PA_AUTH_PROP;
-- DROP INDEX INDEX_PA_BEHAVIOUR_PROP;
-- DROP INDEX INDEX_PA_SA_PROP;
-- DROP INDEX INDEX_PA_SA_CODA_MAX;
-- DROP INDEX INDEX_PA_SA_CODA;
-- DROP INDEX INDEX_PA_SA;
-- DROP INDEX index_porte_applicative_2;
-- DROP INDEX index_porte_applicative_1;
DROP TRIGGER trg_pa_token_ruoli;
DROP TRIGGER trg_pa_token_sa;
DROP TRIGGER trg_pa_aa;
DROP TRIGGER trg_pa_handlers;
DROP TRIGGER trg_pa_transform_risp_hdr;
DROP TRIGGER trg_pa_transform_risp;
DROP TRIGGER trg_pa_transform_url;
DROP TRIGGER trg_pa_transform_hdr;
DROP TRIGGER trg_pa_transform_sa;
DROP TRIGGER trg_pa_transform_soggetti;
DROP TRIGGER trg_pa_transform;
DROP TRIGGER trg_pa_cache_regole;
DROP TRIGGER trg_pa_azioni;
DROP TRIGGER trg_porte_applicative_sa_auth;
DROP TRIGGER trg_pa_soggetti;
DROP TRIGGER trg_pa_scope;
DROP TRIGGER trg_pa_ruoli;
DROP TRIGGER trg_pa_correlazione_risposta;
DROP TRIGGER trg_pa_correlazione;
DROP TRIGGER trg_pa_security_response;
DROP TRIGGER trg_pa_security_request;
DROP TRIGGER trg_pa_mtom_response;
DROP TRIGGER trg_pa_mtom_request;
DROP TRIGGER trg_pa_properties;
DROP TRIGGER trg_pa_ct_properties;
DROP TRIGGER trg_pa_authzc_properties;
DROP TRIGGER trg_pa_authz_properties;
DROP TRIGGER trg_pa_auth_properties;
DROP TRIGGER trg_pa_behaviour_props;
DROP TRIGGER trg_pa_sa_properties;
DROP TRIGGER trg_porte_applicative_sa;
DROP TRIGGER trg_porte_applicative;
DROP TABLE pa_token_ruoli;
DROP TABLE pa_token_sa;
DROP TABLE pa_aa;
DROP TABLE pa_handlers;
DROP TABLE pa_transform_risp_hdr;
DROP TABLE pa_transform_risp;
DROP TABLE pa_transform_url;
DROP TABLE pa_transform_hdr;
DROP TABLE pa_transform_sa;
DROP TABLE pa_transform_soggetti;
DROP TABLE pa_transform;
DROP TABLE pa_cache_regole;
DROP TABLE pa_azioni;
DROP TABLE porte_applicative_sa_auth;
DROP TABLE pa_soggetti;
DROP TABLE pa_scope;
DROP TABLE pa_ruoli;
DROP TABLE pa_correlazione_risposta;
DROP TABLE pa_correlazione;
DROP TABLE pa_security_response;
DROP TABLE pa_security_request;
DROP TABLE pa_mtom_response;
DROP TABLE pa_mtom_request;
DROP TABLE pa_properties;
DROP TABLE pa_ct_properties;
DROP TABLE pa_authzc_properties;
DROP TABLE pa_authz_properties;
DROP TABLE pa_auth_properties;
DROP TABLE pa_behaviour_props;
DROP TABLE pa_sa_properties;
DROP TABLE porte_applicative_sa;
DROP TABLE porte_applicative;
DROP SEQUENCE seq_pa_token_ruoli;
DROP SEQUENCE seq_pa_token_sa;
DROP SEQUENCE seq_pa_aa;
DROP SEQUENCE seq_pa_handlers;
DROP SEQUENCE seq_pa_transform_risp_hdr;
DROP SEQUENCE seq_pa_transform_risp;
DROP SEQUENCE seq_pa_transform_url;
DROP SEQUENCE seq_pa_transform_hdr;
DROP SEQUENCE seq_pa_transform_sa;
DROP SEQUENCE seq_pa_transform_soggetti;
DROP SEQUENCE seq_pa_transform;
DROP SEQUENCE seq_pa_cache_regole;
DROP SEQUENCE seq_pa_azioni;
DROP SEQUENCE seq_porte_applicative_sa_auth;
DROP SEQUENCE seq_pa_soggetti;
DROP SEQUENCE seq_pa_scope;
DROP SEQUENCE seq_pa_ruoli;
DROP SEQUENCE seq_pa_correlazione_risposta;
DROP SEQUENCE seq_pa_correlazione;
DROP SEQUENCE seq_pa_security_response;
DROP SEQUENCE seq_pa_security_request;
DROP SEQUENCE seq_pa_mtom_response;
DROP SEQUENCE seq_pa_mtom_request;
DROP SEQUENCE seq_pa_properties;
DROP SEQUENCE seq_pa_ct_properties;
DROP SEQUENCE seq_pa_authzc_properties;
DROP SEQUENCE seq_pa_authz_properties;
DROP SEQUENCE seq_pa_auth_properties;
DROP SEQUENCE seq_pa_behaviour_props;
DROP SEQUENCE seq_pa_sa_properties;
DROP SEQUENCE seq_porte_applicative_sa;
DROP SEQUENCE seq_porte_applicative;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_PD_TOKEN_SA;
-- DROP INDEX idx_pd_trasf_hdr_resp_1;
-- DROP INDEX idx_pd_trasf_url_1;
-- DROP INDEX idx_pd_trasf_hdr_1;
-- DROP INDEX INDEX_PD_CACHE;
-- DROP INDEX INDEX_PD_CORR_RES;
-- DROP INDEX INDEX_PD_CORR_REQ;
-- DROP INDEX INDEX_PD_WSSRES;
-- DROP INDEX INDEX_PD_WSSREQ;
-- DROP INDEX INDEX_PD_MTOMTRES;
-- DROP INDEX INDEX_PD_MTOMTREQ;
-- DROP INDEX INDEX_PD_PROP;
-- DROP INDEX INDEX_PD_CT_PROP;
-- DROP INDEX idx_pd_ct_props_1;
-- DROP INDEX INDEX_PD_AUTHZC_PROP;
-- DROP INDEX INDEX_PD_AUTHZ_PROP;
-- DROP INDEX INDEX_PD_AUTH_PROP;
-- DROP INDEX INDEX_PD_SA;
-- DROP INDEX index_porte_delegate_2;
-- DROP INDEX index_porte_delegate_1;
DROP TRIGGER trg_pd_token_ruoli;
DROP TRIGGER trg_pd_token_sa;
DROP TRIGGER trg_pd_aa;
DROP TRIGGER trg_pd_handlers;
DROP TRIGGER trg_pd_transform_risp_hdr;
DROP TRIGGER trg_pd_transform_risp;
DROP TRIGGER trg_pd_transform_url;
DROP TRIGGER trg_pd_transform_hdr;
DROP TRIGGER trg_pd_transform_sa;
DROP TRIGGER trg_pd_transform;
DROP TRIGGER trg_pd_cache_regole;
DROP TRIGGER trg_pd_azioni;
DROP TRIGGER trg_pd_scope;
DROP TRIGGER trg_pd_ruoli;
DROP TRIGGER trg_pd_correlazione_risposta;
DROP TRIGGER trg_pd_correlazione;
DROP TRIGGER trg_pd_security_response;
DROP TRIGGER trg_pd_security_request;
DROP TRIGGER trg_pd_mtom_response;
DROP TRIGGER trg_pd_mtom_request;
DROP TRIGGER trg_pd_properties;
DROP TRIGGER trg_pd_ct_properties;
DROP TRIGGER trg_pd_authzc_properties;
DROP TRIGGER trg_pd_authz_properties;
DROP TRIGGER trg_pd_auth_properties;
DROP TRIGGER trg_porte_delegate_sa;
DROP TRIGGER trg_porte_delegate;
DROP TABLE pd_token_ruoli;
DROP TABLE pd_token_sa;
DROP TABLE pd_aa;
DROP TABLE pd_handlers;
DROP TABLE pd_transform_risp_hdr;
DROP TABLE pd_transform_risp;
DROP TABLE pd_transform_url;
DROP TABLE pd_transform_hdr;
DROP TABLE pd_transform_sa;
DROP TABLE pd_transform;
DROP TABLE pd_cache_regole;
DROP TABLE pd_azioni;
DROP TABLE pd_scope;
DROP TABLE pd_ruoli;
DROP TABLE pd_correlazione_risposta;
DROP TABLE pd_correlazione;
DROP TABLE pd_security_response;
DROP TABLE pd_security_request;
DROP TABLE pd_mtom_response;
DROP TABLE pd_mtom_request;
DROP TABLE pd_properties;
DROP TABLE pd_ct_properties;
DROP TABLE pd_authzc_properties;
DROP TABLE pd_authz_properties;
DROP TABLE pd_auth_properties;
DROP TABLE porte_delegate_sa;
DROP TABLE porte_delegate;
DROP SEQUENCE seq_pd_token_ruoli;
DROP SEQUENCE seq_pd_token_sa;
DROP SEQUENCE seq_pd_aa;
DROP SEQUENCE seq_pd_handlers;
DROP SEQUENCE seq_pd_transform_risp_hdr;
DROP SEQUENCE seq_pd_transform_risp;
DROP SEQUENCE seq_pd_transform_url;
DROP SEQUENCE seq_pd_transform_hdr;
DROP SEQUENCE seq_pd_transform_sa;
DROP SEQUENCE seq_pd_transform;
DROP SEQUENCE seq_pd_cache_regole;
DROP SEQUENCE seq_pd_azioni;
DROP SEQUENCE seq_pd_scope;
DROP SEQUENCE seq_pd_ruoli;
DROP SEQUENCE seq_pd_correlazione_risposta;
DROP SEQUENCE seq_pd_correlazione;
DROP SEQUENCE seq_pd_security_response;
DROP SEQUENCE seq_pd_security_request;
DROP SEQUENCE seq_pd_mtom_response;
DROP SEQUENCE seq_pd_mtom_request;
DROP SEQUENCE seq_pd_properties;
DROP SEQUENCE seq_pd_ct_properties;
DROP SEQUENCE seq_pd_authzc_properties;
DROP SEQUENCE seq_pd_authz_properties;
DROP SEQUENCE seq_pd_auth_properties;
DROP SEQUENCE seq_porte_delegate_sa;
DROP SEQUENCE seq_porte_delegate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_SA_PROP;
-- DROP INDEX INDEX_SA_CRED;
-- DROP INDEX INDEX_SA_RUOLI;
-- DROP INDEX index_servizi_applicativi_1;
DROP TRIGGER trg_sa_properties;
DROP TRIGGER trg_sa_credenziali;
DROP TRIGGER trg_sa_ruoli;
DROP TRIGGER trg_servizi_applicativi;
DROP TABLE sa_properties;
DROP TABLE sa_credenziali;
DROP TABLE sa_ruoli;
DROP TABLE servizi_applicativi;
DROP SEQUENCE seq_sa_properties;
DROP SEQUENCE seq_sa_credenziali;
DROP SEQUENCE seq_sa_ruoli;
DROP SEQUENCE seq_servizi_applicativi;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_conf_risorse_contenuti;
DROP TRIGGER trg_configurazione_stati;
DROP TRIGGER trg_config_tran_plugins;
DROP TRIGGER trg_config_transazioni;
DROP TABLE conf_risorse_contenuti;
DROP TABLE configurazione_stati;
DROP TABLE config_tran_plugins;
DROP TABLE config_transazioni;
DROP SEQUENCE seq_conf_risorse_contenuti;
DROP SEQUENCE seq_configurazione_stati;
DROP SEQUENCE seq_config_tran_plugins;
DROP SEQUENCE seq_config_transazioni;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_ricerche_personalizzate;
DROP TABLE ricerche_personalizzate;
DROP SEQUENCE seq_ricerche_personalizzate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_stat_personalizzate;
DROP TABLE stat_personalizzate;
DROP SEQUENCE seq_stat_personalizzate;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_conf_servizi_1;
-- DROP INDEX idx_plug_prop_com_1;
-- DROP INDEX idx_plug_ser_com_1;
DROP TRIGGER trg_plugins_conf_filtri;
DROP TRIGGER trg_plugins_conf_azioni;
DROP TRIGGER trg_plugins_conf_servizi;
DROP TRIGGER trg_plugins_props_comp;
DROP TRIGGER trg_plugins_azioni_comp;
DROP TRIGGER trg_plugins_servizi_comp;
DROP TRIGGER trg_plugins;
DROP TABLE plugins_conf_filtri;
DROP TABLE plugins_conf_azioni;
DROP TABLE plugins_conf_servizi;
DROP TABLE plugins_props_comp;
DROP TABLE plugins_azioni_comp;
DROP TABLE plugins_servizi_comp;
DROP TABLE plugins;
DROP SEQUENCE seq_plugins_conf_filtri;
DROP SEQUENCE seq_plugins_conf_azioni;
DROP SEQUENCE seq_plugins_conf_servizi;
DROP SEQUENCE seq_plugins_props_comp;
DROP SEQUENCE seq_plugins_azioni_comp;
DROP SEQUENCE seq_plugins_servizi_comp;
DROP SEQUENCE seq_plugins;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_AC_SC_SERV;
-- DROP INDEX INDEX_AC_SC_SC;
-- DROP INDEX INDEX_AC_SC;
-- DROP INDEX index_serv_fru_azioni_1;
-- DROP INDEX INDEX_SERV_FRU_SOG;
-- DROP INDEX index_servizi_azioni_1;
-- DROP INDEX INDEX_SERV_SOG;
-- DROP INDEX INDEX_SERV_ACC;
-- DROP INDEX INDEX_AC_SOG;
-- DROP INDEX INDEX_AC_COOP_PAR;
-- DROP INDEX INDEX_OP_MESSAGES;
-- DROP INDEX index_accordi_1;
-- DROP INDEX INDEX_DOC_SEARCH;
DROP TRIGGER trg_acc_serv_componenti;
DROP TRIGGER trg_acc_serv_composti;
DROP TRIGGER trg_servizi_fruitori_azione;
DROP TRIGGER trg_servizi_fruitori_azioni;
DROP TRIGGER trg_servizi_fruitori;
DROP TRIGGER trg_servizi_azione;
DROP TRIGGER trg_servizi_azioni;
DROP TRIGGER trg_servizi;
DROP TRIGGER trg_accordi_coop_partecipanti;
DROP TRIGGER trg_accordi_cooperazione;
DROP TRIGGER trg_accordi_gruppi;
DROP TRIGGER trg_api_resources_parameter;
DROP TRIGGER trg_api_resources_media;
DROP TRIGGER trg_api_resources_response;
DROP TRIGGER trg_api_resources;
DROP TRIGGER trg_operation_messages;
DROP TRIGGER trg_port_type_azioni;
DROP TRIGGER trg_port_type;
DROP TRIGGER trg_accordi_azioni;
DROP TRIGGER trg_accordi;
DROP TRIGGER trg_documenti;
DROP TABLE acc_serv_componenti;
DROP TABLE acc_serv_composti;
DROP TABLE servizi_fruitori_azione;
DROP TABLE servizi_fruitori_azioni;
DROP TABLE servizi_fruitori;
DROP TABLE servizi_azione;
DROP TABLE servizi_azioni;
DROP TABLE servizi;
DROP TABLE accordi_coop_partecipanti;
DROP TABLE accordi_cooperazione;
DROP TABLE accordi_gruppi;
DROP TABLE api_resources_parameter;
DROP TABLE api_resources_media;
DROP TABLE api_resources_response;
DROP TABLE api_resources;
DROP TABLE operation_messages;
DROP TABLE port_type_azioni;
DROP TABLE port_type;
DROP TABLE accordi_azioni;
DROP TABLE accordi;
DROP TABLE documenti;
DROP SEQUENCE seq_acc_serv_componenti;
DROP SEQUENCE seq_acc_serv_composti;
DROP SEQUENCE seq_servizi_fruitori_azione;
DROP SEQUENCE seq_servizi_fruitori_azioni;
DROP SEQUENCE seq_servizi_fruitori;
DROP SEQUENCE seq_servizi_azione;
DROP SEQUENCE seq_servizi_azioni;
DROP SEQUENCE seq_servizi;
DROP SEQUENCE seq_accordi_coop_partecipanti;
DROP SEQUENCE seq_accordi_cooperazione;
DROP SEQUENCE seq_accordi_gruppi;
DROP SEQUENCE seq_api_resources_parameter;
DROP SEQUENCE seq_api_resources_media;
DROP SEQUENCE seq_api_resources_response;
DROP SEQUENCE seq_api_resources;
DROP SEQUENCE seq_operation_messages;
DROP SEQUENCE seq_port_type_azioni;
DROP SEQUENCE seq_port_type;
DROP SEQUENCE seq_accordi_azioni;
DROP SEQUENCE seq_accordi;
DROP SEQUENCE seq_documenti;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_SOGGETTI_PROP;
-- DROP INDEX INDEX_SOGGETTI_CRED;
-- DROP INDEX INDEX_SOGGETTI_RUOLI;
DROP TRIGGER trg_soggetti_properties;
DROP TRIGGER trg_soggetti_credenziali;
DROP TRIGGER trg_soggetti_ruoli;
DROP TRIGGER trg_soggetti;
DROP TABLE soggetti_properties;
DROP TABLE soggetti_credenziali;
DROP TABLE soggetti_ruoli;
DROP TABLE soggetti;
DROP SEQUENCE seq_soggetti_properties;
DROP SEQUENCE seq_soggetti_credenziali;
DROP SEQUENCE seq_soggetti_ruoli;
DROP SEQUENCE seq_soggetti;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_scope;
DROP TABLE scope;
DROP SEQUENCE seq_scope;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_ruoli;
DROP TABLE ruoli;
DROP SEQUENCE seq_ruoli;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_gruppi;
DROP TABLE gruppi;
DROP SEQUENCE seq_gruppi;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_protocol_properties;
DROP TABLE protocol_properties;
DROP SEQUENCE seq_protocol_properties;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_conn_custom_1;
DROP TRIGGER trg_connettori_properties;
DROP TRIGGER trg_connettori_custom;
DROP TRIGGER trg_connettori;
DROP TABLE connettori_properties;
DROP TABLE connettori_custom;
DROP TABLE connettori;
DROP SEQUENCE seq_connettori_properties;
DROP SEQUENCE seq_connettori_custom;
DROP SEQUENCE seq_connettori;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_gest_err_soap_1;
-- DROP INDEX idx_gest_err_trasporto_1;
DROP TRIGGER trg_gestione_errore_soap;
DROP TRIGGER trg_gestione_errore_trasporto;
DROP TRIGGER trg_gestione_errore;
DROP TABLE gestione_errore_soap;
DROP TABLE gestione_errore_trasporto;
DROP TABLE gestione_errore;
DROP SEQUENCE seq_gestione_errore_soap;
DROP SEQUENCE seq_gestione_errore_trasporto;
DROP SEQUENCE seq_gestione_errore;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_pdd;
DROP TABLE pdd;
DROP SEQUENCE seq_pdd;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
DROP TRIGGER trg_db_info;
DROP TABLE db_info_console;
DROP SEQUENCE seq_db_info_console;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX INDEX_REF_SERVIZI;
-- DROP INDEX REMOTE_STORE_CREATE;
-- DROP INDEX REMOTE_STORE_UPDATE;
-- DROP INDEX INDEX_NODI_OP;
-- DROP INDEX index_registro_plug_jar_1;
-- DROP INDEX index_generic_property_1;
-- DROP INDEX index_dump_config_1;
-- DROP INDEX index_filetrace_config_1;
-- DROP INDEX index_tracce_config_1;
DROP TRIGGER trg_servizi_digest_params;
DROP TRIGGER trg_remote_store_key;
DROP TRIGGER trg_remote_store;
DROP TRIGGER trg_nodi_runtime_operations;
DROP TRIGGER trg_nodi_runtime;
DROP TRIGGER trg_config_handlers;
DROP TRIGGER trg_registro_plug_jar;
DROP TRIGGER trg_registro_plugins;
DROP TRIGGER trg_canali_nodi;
DROP TRIGGER trg_canali_configurazione;
DROP TRIGGER trg_generic_property;
DROP TRIGGER trg_generic_properties;
DROP TRIGGER trg_pdd_sys_props;
DROP TRIGGER trg_servizi_pdd_filtri;
DROP TRIGGER trg_servizi_pdd;
DROP TRIGGER trg_tracce_ds_prop;
DROP TRIGGER trg_tracce_ds;
DROP TRIGGER trg_msgdiag_ds_prop;
DROP TRIGGER trg_msgdiag_ds;
DROP TRIGGER trg_dump_appender_prop;
DROP TRIGGER trg_dump_appender;
DROP TRIGGER trg_dump_config_regola;
DROP TRIGGER trg_dump_config;
DROP TRIGGER trg_filetrace_config;
DROP TRIGGER trg_tracce_config;
DROP TRIGGER trg_tracce_appender_prop;
DROP TRIGGER trg_tracce_appender;
DROP TRIGGER trg_msgdiag_appender_prop;
DROP TRIGGER trg_msgdiag_appender;
DROP TRIGGER trg_config_url_regole;
DROP TRIGGER trg_config_url_invocazione;
DROP TRIGGER trg_configurazione;
DROP TRIGGER trg_config_cache_regole;
DROP TRIGGER trg_routing;
DROP TRIGGER trg_registri;
DROP TABLE servizi_digest_params;
DROP TABLE remote_store_key;
DROP TABLE remote_store;
DROP TABLE nodi_runtime_operations;
DROP TABLE nodi_runtime;
DROP TABLE config_handlers;
DROP TABLE registro_plug_jar;
DROP TABLE registro_plugins;
DROP TABLE canali_nodi;
DROP TABLE canali_configurazione;
DROP TABLE generic_property;
DROP TABLE generic_properties;
DROP TABLE pdd_sys_props;
DROP TABLE servizi_pdd_filtri;
DROP TABLE servizi_pdd;
DROP TABLE tracce_ds_prop;
DROP TABLE tracce_ds;
DROP TABLE msgdiag_ds_prop;
DROP TABLE msgdiag_ds;
DROP TABLE dump_appender_prop;
DROP TABLE dump_appender;
DROP TABLE dump_config_regola;
DROP TABLE dump_config;
DROP TABLE filetrace_config;
DROP TABLE tracce_config;
DROP TABLE tracce_appender_prop;
DROP TABLE tracce_appender;
DROP TABLE msgdiag_appender_prop;
DROP TABLE msgdiag_appender;
DROP TABLE config_url_regole;
DROP TABLE config_url_invocazione;
DROP TABLE configurazione;
DROP TABLE config_cache_regole;
DROP TABLE routing;
DROP TABLE registri;
DROP SEQUENCE seq_servizi_digest_params;
DROP SEQUENCE seq_remote_store_key;
DROP SEQUENCE seq_remote_store;
DROP SEQUENCE seq_nodi_runtime_operations;
DROP SEQUENCE seq_nodi_runtime;
DROP SEQUENCE seq_config_handlers;
DROP SEQUENCE seq_registro_plug_jar;
DROP SEQUENCE seq_registro_plugins;
DROP SEQUENCE seq_canali_nodi;
DROP SEQUENCE seq_canali_configurazione;
DROP SEQUENCE seq_generic_property;
DROP SEQUENCE seq_generic_properties;
DROP SEQUENCE seq_pdd_sys_props;
DROP SEQUENCE seq_servizi_pdd_filtri;
DROP SEQUENCE seq_servizi_pdd;
DROP SEQUENCE seq_tracce_ds_prop;
DROP SEQUENCE seq_tracce_ds;
DROP SEQUENCE seq_msgdiag_ds_prop;
DROP SEQUENCE seq_msgdiag_ds;
DROP SEQUENCE seq_dump_appender_prop;
DROP SEQUENCE seq_dump_appender;
DROP SEQUENCE seq_dump_config_regola;
DROP SEQUENCE seq_dump_config;
DROP SEQUENCE seq_filetrace_config;
DROP SEQUENCE seq_tracce_config;
DROP SEQUENCE seq_tracce_appender_prop;
DROP SEQUENCE seq_tracce_appender;
DROP SEQUENCE seq_msgdiag_appender_prop;
DROP SEQUENCE seq_msgdiag_appender;
DROP SEQUENCE seq_config_url_regole;
DROP SEQUENCE seq_config_url_invocazione;
DROP SEQUENCE seq_configurazione;
DROP SEQUENCE seq_config_cache_regole;
DROP SEQUENCE seq_routing;
DROP SEQUENCE seq_registri;


-- govway
		  		
-- Gli indici vengono eliminati automaticamente una volta eliminata la tabella
-- DROP INDEX idx_cong_att_policy_1;
-- DROP INDEX idx_rt_prop_policy_1;
DROP TRIGGER trg_ct_active_policy;
DROP TRIGGER trg_ct_config_policy;
DROP TRIGGER trg_ct_rt_props;
DROP TRIGGER trg_ct_config;
DROP TABLE ct_active_policy;
DROP TABLE ct_config_policy;
DROP TABLE ct_rt_props;
DROP TABLE ct_config;
DROP SEQUENCE seq_ct_active_policy;
DROP SEQUENCE seq_ct_config_policy;
DROP SEQUENCE seq_ct_rt_props;
DROP SEQUENCE seq_ct_config;


-- govway
		  		
